@@ -59,6 +59,20 @@ macro_rules! retry_loop {
     };
 }
 
+#[cfg(test)]
+#[macro_export]
+/// Helper for tests to retry an operation awaiting for a successful response result
+macro_rules! retry_err_loop {
+    ($async_func:expr) => {
+        loop {
+            match $async_func.await {
+                Ok(_) => tokio::time::sleep(std::time::Duration::from_millis(200)).await,
+                Err(err) => break err,
+            }
+        }
+    };
+}
+
 #[cfg(test)]
 #[macro_export]
 /// Helper for tests to retry an operation awaiting for a specific result
